@@ -36,6 +36,7 @@
 #include "gchempaint-config.h"
 #include "application.h"
 #include "document.h"
+#include "electron.h"
 #include "text.h"
 #include "plugin.h"
 #include "filechooser.h"
@@ -45,6 +46,7 @@
 #include <bonobo/bonobo-ui-util.h>
 #include <sys/stat.h>
 #include <gconf/gconf-client.h>
+#include <gnome-vfs-module-2.0/libgnomevfs/gnome-vfs-mime.h>
 
 enum gcpFileTypes
 {
@@ -104,6 +106,9 @@ static Object* CreateFragment()
 
 list<gcpApplication*> Apps;
 bool	gcpApplication::m_bInit = false;
+bool	gcpApplication::m_Have_ps2eps = false;
+bool	gcpApplication::m_Have_Ghemical = false;
+map<string, string> gcpApplication::m_SupportedPixbufFormats;
 
 #warning "the following lines should be removed for stable releases"
 #undef PACKAGE
@@ -164,6 +169,38 @@ gcpApplication::gcpApplication ()
 	}
 
 	if (!m_bInit) {
+		// Check for programs
+		char *result = NULL;;
+		// check for ps2eps
+		m_Have_ps2eps = (g_spawn_command_line_sync ("which ps2eps", &result, NULL, NULL, NULL)
+			&& result && strlen (result));
+		if (result) {
+			g_free (result);
+			result = NULL;
+		}
+		// check for ghemical
+		m_Have_Ghemical = (g_spawn_command_line_sync ("which ghemical", &result, NULL, NULL, NULL)
+			&& result && strlen (result));
+		if (result)
+			g_free (result);
+		// check supported pixbuf formats
+		GSList *formats = gdk_pixbuf_get_formats ();
+		GSList *l = formats;
+		GdkPixbufFormat *format;
+		char **mimes, **mime;
+		while (l) {
+			format = (GdkPixbufFormat*) l->data;
+			if (gdk_pixbuf_format_is_writable (format)) {
+				mimes = gdk_pixbuf_format_get_mime_types (format);
+				mime = mimes;
+				while (*mime)
+					m_SupportedPixbufFormats[*mime++] = gdk_pixbuf_format_get_name (format);
+				g_strfreev (mimes);
+			}
+			l = l->next;
+		}
+		g_slist_free (formats);
+
 		gcpText::InitTags(FontName);
 		// Initialize types
 		Object::AddType ("molecule", CreateMolecule, MoleculeType);
@@ -177,6 +214,7 @@ gcpApplication::gcpApplication ()
 		Object::AddType("mesomery-arrow", CreateMesomeryArrow, MesomeryArrowType);
 		Object::AddType("text", CreateText, TextType);
 		Object::AddType("fragment", CreateFragment, FragmentType);
+		ElectronType = Object::AddType ("electron", NULL);
 		//Add rules
 		Object::AddRule ("reaction", RuleMustContain, "reaction-step");
 		Object::AddRule ("reaction-step", RuleMustContain, "reactant");
@@ -188,6 +226,11 @@ gcpApplication::gcpApplication ()
 		Object::AddRule ("mesomery", RuleMustContain, "molecule");
 		Object::AddRule ("mesomery", RuleMustContain, "mesomery-arrow");
 		Object::AddRule ("mesomery-arrow", RuleMustBeIn, "mesomery");
+
+		// Create global signal ids
+		OnChangedSignal = Object::CreateNewSignalId ();
+		OnDeleteSignal = Object::CreateNewSignalId ();
+
 		gcpPlugin::LoadPlugins();
 		m_bInit = true;
 	}
@@ -640,3 +683,74 @@ void gcpApplication::OnShowElements ()
 	}
 	else gdk_window_raise (GTK_WIDGET(dlg->GetWindow())->window); 
 }
+
+void gcpApplication::OnSaveAsImage ()
+{
+	char* filename;
+	GtkFileChooser *dialog = (GtkFileChooser*) gtk_file_chooser_dialog_new (
+															_("Save as image"),
+															GetWindow(),
+															GTK_FILE_CHOOSER_ACTION_SAVE,
+															GTK_STOCK_SAVE, GTK_RESPONSE_ACCEPT,
+															GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+															NULL);
+	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_OK);
+	GtkFileFilter* filter = gtk_file_filter_new ();
+	map<string, string>::iterator i, end = m_SupportedPixbufFormats.end ();
+	for (i = m_SupportedPixbufFormats.begin (); i != end; i++)
+		gtk_file_filter_add_mime_type (filter, (*i).first.c_str ());
+	gtk_file_filter_add_mime_type (filter, "image/svg+xml");
+	if (m_Have_ps2eps)
+		gtk_file_filter_add_mime_type (filter, "image/x-eps");
+	gtk_file_chooser_set_filter (dialog, filter);
+	while (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_ACCEPT) {
+		filename = gtk_file_chooser_get_filename (dialog);
+		if (!filename || !strlen(filename) || filename[strlen(filename) - 1] == '/') {
+			GtkWidget* message = gtk_message_dialog_new (GTK_WINDOW (dialog), GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, 
+																_("Please enter a file name,\nnot a directory"));
+			gtk_dialog_run (GTK_DIALOG (message));
+			gtk_widget_destroy (message);
+			continue;
+		}
+		struct stat buf;
+		gint err;
+		err = stat(filename, &buf);
+		gint result = GTK_RESPONSE_YES;
+		if (!err)
+		{
+			gchar * message = g_strdup_printf(_("File %s\nexists, overwrite?"), filename);
+			GtkDialog* Box = GTK_DIALOG(gtk_message_dialog_new(NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_QUESTION, GTK_BUTTONS_YES_NO, message));
+			result = gtk_dialog_run(Box);
+			gtk_widget_destroy(GTK_WIDGET(Box));
+			g_free(message);
+			if (result != GTK_RESPONSE_YES)
+				continue;
+		}
+		const char* mime_type = gnome_vfs_mime_type_from_name (filename);
+		if (m_SupportedPixbufFormats.find (mime_type) != m_SupportedPixbufFormats.end())
+			m_pActiveDoc->ExportImage (filename, m_SupportedPixbufFormats[mime_type].c_str ());
+		else if (!strcmp (mime_type, "image/x-eps")) {
+			if (m_Have_ps2eps)
+				m_pActiveDoc->ExportImage (filename, "eps");
+			else {
+				GtkWidget* message = gtk_message_dialog_new (GTK_WINDOW (dialog), GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, 
+																	"Can't export eps files, please install ps2eps");
+				gtk_dialog_run (GTK_DIALOG (message));
+				gtk_widget_destroy (message);
+			}
+		}
+		else if (!strcmp (mime_type, "image/svg+xml")) {
+			m_pActiveDoc->ExportImage (filename, "svg");
+		}
+		else {
+			GtkWidget* message = gtk_message_dialog_new (GTK_WINDOW (dialog), GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, 
+																_("Sorry, format not supported !"));
+			gtk_dialog_run (GTK_DIALOG (message));
+			gtk_widget_destroy (message);
+			continue;
+		}
+		break;//replace with sensible code
+	}
+	gtk_widget_destroy (GTK_WIDGET (dialog));
+	return;	
+}
