@@ -50,6 +50,9 @@ namespace OpenBabel
 using namespace OpenBabel;
 using namespace std;
 
+extern SignalId OnChangedSignal;
+extern SignalId OnDeleteSignal;
+
 class gcpView;
 class gcpApplication;
 class gcpDocPropDlg;
@@ -118,6 +121,7 @@ public:
 	bool GetEditable() {return m_bWriteable;}
 	gcpApplication* GetApplication() {return m_pApp;}
 	bool IsDirty () {return m_bDirty;}
+	void ExportImage (const char* filename, const char* type);
 
 private:
 	void RemoveAtom(gcpAtom* pAtom);
