@@ -43,12 +43,12 @@ gcpPlugin::~gcpPlugin ()
 
 void gcpPlugin::LoadPlugins ()
 {
-	GDir* dir = g_dir_open (DATADIR"/gchempaint/plugins", 0, NULL);
+	GDir* dir = g_dir_open (LIBDIR"/gchempaint/plugins", 0, NULL);
 	if (dir ==  NULL) return;
 	const char* name;
 	while (name = g_dir_read_name (dir)) {
 		if (strcmp (name + strlen (name) - 3, ".so")) continue;
-		name = g_strconcat (DATADIR"/gchempaint/plugins/", name);
+		name = g_strconcat (LIBDIR"/gchempaint/plugins/", name);
 		if (!dlopen (name, RTLD_NOW)) puts (dlerror());
 		g_free ((void*) name);
 	}
