@@ -6,7 +6,7 @@
  *
  * Copyright (C) 2002-2004
  *
- * Developed by Jean Bréfort <jean.brefort@ac-dijon.fr>
+ * Developed by Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -321,7 +321,10 @@ bool gcpText::LoadNode(xmlNodePtr node, GtkTextIter* CurIter)
 	if (!strcmp((const char*)node->name, "text"))
 	{
 		tmp = (char*) xmlNodeGetContent(node);
-		gtk_text_buffer_insert(m_buf, CurIter, tmp, -1);
+		if (tmp) {
+			gtk_text_buffer_insert(m_buf, CurIter, tmp, -1);
+			xmlFree (tmp);
+		}
 		return true;
 	}
 	else if (!strcmp((const char*)node->name, "br"))
@@ -337,22 +340,24 @@ bool gcpText::LoadNode(xmlNodePtr node, GtkTextIter* CurIter)
 	else if (!strcmp((const char*)node->name, "sup")) return LoadTaggedNode(node, CurIter, "superscript");
 	else if (!strcmp((const char*)node->name, "font"))
 	{
-		char* TagName = (char*)xmlGetProp(node, (xmlChar*)"name");
+		char* TagName = (char*) xmlGetProp (node, (xmlChar*) "name");
 		if (!TagName) return false;
-		GtkTextTag* tag = gtk_text_tag_table_lookup(TextTagTable, TagName);
+		GtkTextTag* tag = gtk_text_tag_table_lookup (TextTagTable, TagName);
 		if (!tag)
 		{
-			PangoFontDescription* pfd =pango_font_description_from_string(TagName);
-			GtkTextTag* tag = gtk_text_tag_new(TagName);
-			g_object_set(G_OBJECT(tag),
-								"family", pango_font_description_get_family(pfd),
-								"size", pango_font_description_get_size(pfd),
+			PangoFontDescription* pfd =pango_font_description_from_string (TagName);
+			GtkTextTag* tag = gtk_text_tag_new (TagName);
+			g_object_set (G_OBJECT (tag),
+								"family", pango_font_description_get_family (pfd),
+								"size", pango_font_description_get_size (pfd),
 								NULL);
-			pango_font_description_free(pfd);
-			gtk_text_tag_table_add(TextTagTable, tag);
-			g_object_unref((GObject*)tag);
+			pango_font_description_free (pfd);
+			gtk_text_tag_table_add (TextTagTable, tag);
+			g_object_unref ((GObject*) tag);
 		}
-		return LoadTaggedNode(node, CurIter, TagName);
+		bool result = LoadTaggedNode (node, CurIter, TagName);
+		xmlFree (TagName);
+		return result;
 	}
 	else return false;
 }
@@ -450,13 +455,20 @@ bool gcpText::OnChanged(GtkTextBuffer *textbuffer)
 	m_height = 1;
 	bool bNotEnd = true;
 	m_length = 0;
+	if (!gtk_text_buffer_get_char_count (m_buf)) {
+		gnome_canvas_rich_text_ext_get_iter_location(text, &iter, &rect);
+		m_height = rect.height + 1;
+		m_length = 1;
+		pView->Update (this);
+		return true;
+	}
 	while (bNotEnd)
 	{
 		bNotEnd = gtk_text_iter_forward_to_line_end(&iter);
 		gnome_canvas_rich_text_ext_get_iter_location(text, &iter, &rect);
 		if (m_length <= rect.x + rect.width) m_length = rect.x + rect.width + 1;
 		m_height += rect.height;
-		if (m_height <= rect.height + y0) m_height = rect.height + y0+ 1;
+		if (m_height <= rect.height + y0) m_height = rect.height + y0 + 1;
 		if (rect.y != y0)
 		{
 			while (rect.y != y0)
@@ -478,6 +490,7 @@ bool gcpText::OnChanged(GtkTextBuffer *textbuffer)
 		gnome_canvas_rich_text_ext_get_iter_location(text, &iter, &rect);
 		y0 = rect.y;
 	}
+	EmitSignal (OnChangedSignal);
 	return true;
 }
 
