@@ -96,7 +96,7 @@ void gcpTool::OnRelease(double x, double y, unsigned int state)
 	g_signal_emit_by_name(m_pWidget, "update_bounds");
 }
 
-bool gcpTool::OnRightButtonClicked (gcpView* pView, Object* pObject, double x, double y)
+bool gcpTool::OnRightButtonClicked (gcpView* pView, Object* pObject, double x, double y, GtkUIManager *UIManager)
 {
 	m_pObject = pObject;
 	m_pView = pView;
@@ -107,8 +107,9 @@ bool gcpTool::OnRightButtonClicked (gcpView* pView, Object* pObject, double x, d
 	m_dZoomFactor = m_pView->GetZoomFactor();
 	m_x = x;
 	m_y = y;
-	OnRightButtonClicked ();
+	bool res = OnRightButtonClicked (UIManager);
 	m_pObject = NULL;
+	return res;
 }
 
 bool gcpTool::Activate(bool bState)
@@ -151,7 +152,7 @@ void gcpTool::OnRelease()
 {
 }
 
-bool gcpTool::OnRightButtonClicked()
+bool gcpTool::OnRightButtonClicked(GtkUIManager *UIManager)
 {
 	return false;
 }
