@@ -86,6 +86,7 @@ public:
 	void OnSelectAll();
 	bool IsEmbedded() {return m_bEmbedded;}
 	int GetNbWidgets () {return m_Widgets.size ();}
+	void ExportImage (const char* filename, const char* type);
 
 	//Implementation
 private:
@@ -115,6 +116,8 @@ private:
 	double m_lastx, m_lasty;
 	GnomeCanvasRichTextExt* m_ActiveRichText;
 	bool m_bEmbedded;
+	GtkUIManager *m_UIManager;
+	bool m_Dragging;
 };
 
 bool on_event(GnomeCanvasItem *item, GdkEvent *event, GtkWidget* widget);
