@@ -42,11 +42,13 @@ void gnome_print_pango_layout_print (GnomePrintContext *gpc, PangoLayout* pl);
 static void gnome_canvas_text_ext_class_init   (GnomeCanvasTextExtClass *class);
 static void gnome_canvas_text_ext_init         (GnomeCanvasTextExt     *line);
 static void gnome_canvas_text_ext_print       (GPrintable *gprintable, GnomePrintContext *pc);
+static void gnome_canvas_text_ext_export_svg   (GPrintable *gprintable, xmlDocPtr doc, xmlNodePtr node);
 
 static void
 gnome_canvas_text_print_init (GPrintableIface *iface)
 {
 	iface->print = gnome_canvas_text_ext_print;
+	iface->export_svg = gnome_canvas_text_ext_export_svg;
 }
 
 GType
@@ -144,8 +146,67 @@ void gnome_canvas_text_ext_print (GPrintable *printable, GnomePrintContext *pc)
 	default:
 		break;
 	}
-g_warning("text position %g %g",text->x,text->y);
 	gnome_print_translate (pc, x, y);
 	gnome_print_pango_layout_print (pc, text->layout);
 	gnome_print_grestore (pc);
 }
+
+extern void pango_layout_to_svg (PangoLayout* layout, xmlDocPtr doc, xmlNodePtr node, double x, double y);
+
+static void
+gnome_canvas_text_ext_export_svg (GPrintable *printable, xmlDocPtr doc, xmlNodePtr node)
+{
+	GnomeCanvasText *text;
+	double x , y;
+	xmlNodePtr child;
+	char *buf;
+
+	g_return_if_fail (GNOME_IS_CANVAS_TEXT_EXT (printable));
+	text = GNOME_CANVAS_TEXT (printable);
+	x = text->x;
+	y = text->y;
+	switch (text->anchor) {
+	case GTK_ANCHOR_NW:
+	case GTK_ANCHOR_W:
+	case GTK_ANCHOR_SW:
+		break;
+
+	case GTK_ANCHOR_N:
+	case GTK_ANCHOR_CENTER:
+	case GTK_ANCHOR_S:
+		x -= text->max_width / 2;
+		break;
+
+	case GTK_ANCHOR_NE:
+	case GTK_ANCHOR_E:
+	case GTK_ANCHOR_SE:
+		x -= text->max_width;
+		break;
+
+	default:
+		break;
+	}
+
+	switch (text->anchor) {
+	case GTK_ANCHOR_NW:
+	case GTK_ANCHOR_N:
+	case GTK_ANCHOR_NE:
+		break;
+
+	case GTK_ANCHOR_W:
+	case GTK_ANCHOR_CENTER:
+	case GTK_ANCHOR_E:
+		y -= text->height / 2;
+		break;
+
+	case GTK_ANCHOR_SW:
+	case GTK_ANCHOR_S:
+	case GTK_ANCHOR_SE:
+		y -= text->height;
+		break;
+
+	default:
+		break;
+	}
+	pango_layout_to_svg (text->layout, doc, node, x, y);
+}
