@@ -30,10 +30,15 @@
 #include "lib/tool.h"
 #include "lib/arrow.h"
 
+enum {
+	gcpDoubleHeadedArrow = gcpReversibleArrow + 1,
+	gcpDoubleQueuedArrow
+};
+
 class gcpArrowTool: public gcpTool
 {
 public:
-	gcpArrowTool(gcpApplication* App, gcpArrowType ArrowType = gcpSimpleArrow);
+	gcpArrowTool(gcpApplication* App, unsigned ArrowType = gcpSimpleArrow);
 	~gcpArrowTool();
 	
 	virtual bool OnClicked();
@@ -45,7 +50,7 @@ protected:
 
 private:
 	double m_dAngle;
-	gcpArrowType m_ArrowType;
+	unsigned m_ArrowType;
 };
 
 #endif	//GCHEMPAINT_ARROW_TOOL_H
