@@ -156,12 +156,17 @@ void gcpEraserTool::OnRelease()
 		return;
 	}
 	gcpDocument* pDoc = m_pView->GetDoc();
-		if (m_pObject->GetType() == AtomType)
-		{
-			Object* parent = m_pObject->GetParent();
-			if (parent->GetType() == FragmentType)	m_pObject = parent;
-		}
+	if (m_pObject->GetType() == AtomType)
+	{
+		Object* parent = m_pObject->GetParent();
+		if (parent->GetType() == FragmentType)	m_pObject = parent;
+	}
+	m_pObject->EmitSignal (OnDeleteSignal);
+	m_pItem = NULL;
+	if (m_pData->Items[m_pObject] == NULL) {
+		m_pData->Items.erase(m_pObject);
+		return;
+	}
 	pDoc->Remove(m_pObject);
 	pDoc->FinishOperation();
-	m_pItem = NULL;
 }
