@@ -32,22 +32,10 @@
 #include "texttool.h"
 #include "fragmenttool.h"
 
-static Object* CreateText()
-{
-	return new gcpText();
-}
-
-static Object* CreateFragment()
-{
-	return new gcpFragment();
-}
-
 gcpTextPlugin plugin;
 
 gcpTextPlugin::gcpTextPlugin(): gcpPlugin()
 {
-	Object::AddType("text", CreateText, TextType);
-	Object::AddType("fragment", CreateFragment, FragmentType);
 }
 
 gcpTextPlugin::~gcpTextPlugin()
